@@ -1,6 +1,6 @@
 # -*- coding: UTF-8 -*-
 """
-@Project ：DamoFree
+@Project ：pydmdll
 @File ：damo.py
 @Author ：Gao yongxian
 @Date ：2021/10/23 12:47
@@ -14,7 +14,7 @@ from win32com.client import Dispatch
 
 class DM:
     """
-       FreeDamo是一个实现大漠插件免费功能的Python包，无需手动注册dll，直接导入包使用。可以模拟驱动级的鼠标键盘输入。不支持后台的鼠标键盘，以及所有付费功能都不支持。
+       pydmdll是一个实现大漠插件免费功能的Python包，无需手动注册dll，直接导入包使用。可以模拟驱动级的鼠标键盘输入。不支持后台的鼠标键盘，以及所有付费功能都不支持。
     """
 
     def __init__(self, dm_dll_path: str = None) -> None:
@@ -25,9 +25,12 @@ class DM:
             dm_dll_path: dm.dll路径。如果你想打包的话记得传入本地dll路径，本机使用不需要传入，会调用默认包目录下的dll文件
         """
         self.dm_dll_path = dm_dll_path
-        if (dm_dll_path is None):
+        if dm_dll_path is None:
             # 没指定dm.dll就用默认的dm.dll
             self.dm_dll_path = os.path.join(os.path.dirname(__file__.replace('/', '\\')), 'dm.dll')
+            print("self.dm_dll_path",self.dm_dll_path)
+            # self.dm_dll_path = os.path.join(os.path.dirname(sys.modules["pydmdll"].__file__), 'dm.dll')
+            # print("self.dm_dll_path",self.dm_dll_path)
 
         self.cmd_dll = 'regsvr32 \"' + self.dm_dll_path + '\" /s'
 
@@ -107,6 +110,7 @@ class DM:
         ret = '版本： ' + str(self.ver()) + '，ID：' + str(self.GetID())
         return ret
 
+
     def Un_reg(self) -> None:
         '''
         取消已经注册的dm.dll
